@@ -10,4 +10,8 @@ from influxdb import InfluxDBClient
 from mqtt_to_influx.parse_options import args
 
 # FIXME: This may create one client per import.. let's see
-influx_client = InfluxDBClient(args.influx_db_host, args.influx_db_port, database=args.influx_db_name)
+influx_client = InfluxDBClient(args.influx_db_host, 
+                               args.influx_db_port,
+                               database = args.influx_db_name,
+                               username = args.influx_db_user,
+                               password = args.influx_db_password)
