@@ -8,11 +8,11 @@
 # }}}
 import json
 import logging
+import time
 from mqtt_to_influx.config import CONFIG
 from mqtt_to_influx.rel_h_t_abs import rel_hum_to_abs_hum
 from mqtt_to_influx.influx_client import influx_client
 import paho.mqtt.client as mqtt
-from time import sleep
 
 logger = logging.getLogger(__name__)
 
